@@ -75,6 +75,15 @@ def on_proc_init(proc: "Proc"):
     """
 
 
+@plugin.spec
+def on_proc_input_computed(proc: "Proc"):
+    """Called after process input data is computed.
+
+    Args:
+        proc: The Proc object
+    """
+
+
 @plugin.spec
 async def on_proc_start(proc: "Proc"):
     """When a process is starting
