@@ -267,6 +267,7 @@ class Proc(ABC, metaclass=ProcMeta):
             if locs[key] is not None:
                 kwargs[key] = locs[key]
 
+        kwargs["__doc__"] = proc.__doc__
         return type(name, (proc,), kwargs)
 
     def __init_subclass__(cls) -> None:
@@ -449,7 +450,8 @@ class Proc(ABC, metaclass=ProcMeta):
                 self.pbar.update_job_running()
                 self.pbar.update_job_succeeded()
                 job.status = JobStatus.FINISHED
-            await self.xqute.put(job)
+            else:
+                await self.xqute.put(job)
         if cached_jobs:
             self.log("info", "Cached jobs: [%s]", brief_list(cached_jobs))
         await self.xqute.run_until_complete()
@@ -617,7 +619,7 @@ class Proc(ABC, metaclass=ProcMeta):
 
         out.data = out.data.rename(
             columns=dict(zip(rest_cols[:len_needed_cols], needed_cols))
-        ).loc[:, out.type]
+        ).loc[:, list(out.type)]
 
         return out
 
